@@ -112,10 +112,16 @@ impl Stash {
 
     /// Register that an update operation has completed. Time is incremented.
     /// Stashed pages may be freed.
-    pub fn end_write(&mut self) {
+    pub fn end_write(&mut self) -> usize {
         // println!("Stash tick time={}", self.time);
+        let result = if let Some(u) = self.updates.get(&self.time) {
+            u.len()
+        } else {
+            0
+        };
         self.time += 1;
         self.trim();
+        result
     }
 
     /// Trim due to a read or write ending.
@@ -245,17 +251,18 @@ impl AccessPagedData {
     }
 
     /// Commit changes to underlying file ( or rollback logical page allocations ).
-    pub fn save(&self, op: SaveOp) {
+    pub fn save(&self, op: SaveOp) -> usize {
         debug_assert!(self.writer);
         match op {
             SaveOp::Save => {
                 self.spd.file.write().unwrap().save();
-                self.spd.stash.write().unwrap().end_write();
+                self.spd.stash.write().unwrap().end_write()
             }
             SaveOp::RollBack => {
                 // Note: rollback happens before any pages are updated.
                 // However logical page allocations need to be rolled back.
                 self.spd.file.write().unwrap().rollback();
+                0
             }
         }
     }
